summaryrefslogtreecommitdiffstats
path: root/dcop/dcopobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'dcop/dcopobject.h')
-rw-r--r--dcop/dcopobject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/dcop/dcopobject.h b/dcop/dcopobject.h
index 2040379b2..d1f19ccb4 100644
--- a/dcop/dcopobject.h
+++ b/dcop/dcopobject.h
@@ -299,16 +299,16 @@ public:
static bool hasObject(const TQCString &objId);
/**
* Try to find a dcop object with the given id.
* This function does not query the DCOPObjectProxy.
* @param objId the object id to search
* @return the DCOPObject for the id @p objId.
*/
- static DCOPObject *find(const TQCString &objId);
+ static DCOPObject *tqfind(const TQCString &objId);
/**
* Tries to find an object using a partial object id.
* This function is used for multicasting a DCOP message to
* several objects inside a single process.
*
@@ -299,16 +299,16 @@ public:
static bool hasObject(const TQCString &objId);
/**
- * Try to find a dcop object with the given id.
+ * Try to tqfind a dcop object with the given id.
* This function does not query the DCOPObjectProxy.
* @param objId the object id to search
@@ -299,16 +299,16 @@ public:
/**
- * Tries to find an object using a partial object id.
+ * Tries to tqfind an object using a partial object id.
* This function is used for multicasting a DCOP message to
* several objects inside a single process.